Will wrap some embeds with bootstrap codes (ex: youtube, vimeo...) as a way to make them responsive. The code added in this fork is the add_bs4_styling() function and can be found in the parsers.py file. It is intended to work with flask applications only.

For the fix to work you have to include `STYLE_EMBED = True` in your config file.

